==> disent-0.2.1.tar.gz: disent-0.2.1/disent/dataset/sampling/_random__any.py <==
#  ~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
#  MIT License
#
#  Copyright (c) 2021 Nathan Juraj Michlo
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
#  ~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~

from typing import Tuple

import numpy as np
from disent.dataset.sampling._base import BaseDisentSampler


# ========================================================================= #
# Randomly Paired Dataset                                                   #
# ========================================================================= #


class RandomSampler(BaseDisentSampler):

    def uninit_copy(self) -> 'RandomSampler':
        return RandomSampler(num_samples=self.num_samples)

    def __init__(self, num_samples=1):
        super().__init__(num_samples=num_samples)

    def _init(self, dataset):
        self._len = len(dataset)

    def _sample_idx(self, idx: int) -> Tuple[int, ...]:
        # sample indices
        return (idx, *np.random.randint(0, self._len, size=self._num_samples-1))


# ========================================================================= #
# End                                                                       #
# ========================================================================= #

==> disent-0.8.0.tar.gz: disent-0.8.0/disent/dataset/sampling/_random__any.py <==
#  ~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
#  MIT License
#
#  Copyright (c) 2021 Nathan Juraj Michlo
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
#  ~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~

from typing import Tuple

import numpy as np

from disent.dataset.sampling._base import BaseDisentSampler

# ========================================================================= #
# Randomly Paired Dataset                                                   #
# ========================================================================= #


class RandomSampler(BaseDisentSampler):
    def uninit_copy(self) -> "RandomSampler":
        return RandomSampler(num_samples=self.num_samples)

    def __init__(self, num_samples=1):
        super().__init__(num_samples=num_samples)

    def _init(self, dataset):
        self._len = len(dataset)

    def _sample_idx(self, idx: int) -> Tuple[int, ...]:
        # sample indices
        return (idx, *np.random.randint(0, self._len, size=self._num_samples - 1))


# ========================================================================= #
# End                                                                       #
# ========================================================================= #
